# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`nhc`](#nhc): Manage Node Health Check (NHC)
* [`nhc::config`](#nhc--config): private class
* [`nhc::install`](#nhc--install): private class

### Defined types

* [`nhc::conf`](#nhc--conf): Manage NHC configurations
* [`nhc::custom_check`](#nhc--custom_check): Add NHC custom check file

## Classes

### <a name="nhc"></a>`nhc`

Manage Node Health Check (NHC)

#### Examples

##### 

```puppet
include ::nhc
```

#### Parameters

The following parameters are available in the `nhc` class:

* [`ensure`](#-nhc--ensure)
* [`install_method`](#-nhc--install_method)
* [`package_ensure`](#-nhc--package_ensure)
* [`version`](#-nhc--version)
* [`package_release`](#-nhc--package_release)
* [`install_source`](#-nhc--install_source)
* [`package_name`](#-nhc--package_name)
* [`repo_name`](#-nhc--repo_name)
* [`source_dependencies`](#-nhc--source_dependencies)
* [`libexec_dir`](#-nhc--libexec_dir)
* [`checks`](#-nhc--checks)
* [`settings`](#-nhc--settings)
* [`settings_host`](#-nhc--settings_host)
* [`config_overrides`](#-nhc--config_overrides)
* [`detached_mode`](#-nhc--detached_mode)
* [`detached_mode_fail_nodata`](#-nhc--detached_mode_fail_nodata)
* [`program_name`](#-nhc--program_name)
* [`conf_dir`](#-nhc--conf_dir)
* [`conf_file`](#-nhc--conf_file)
* [`include_dir`](#-nhc--include_dir)
* [`log_file`](#-nhc--log_file)
* [`sysconfig_path`](#-nhc--sysconfig_path)
* [`manage_logrotate`](#-nhc--manage_logrotate)
* [`log_rotate_every`](#-nhc--log_rotate_every)
* [`custom_checks`](#-nhc--custom_checks)

##### <a name="-nhc--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of NHC resources

Default value: `'present'`

##### <a name="-nhc--install_method"></a>`install_method`

Data type: `Enum['repo','package','source']`

The method used to install NHC.
Using `repo` will require the `Yumrepo` resource if `repo_name` is defined.

Default value: `'source'`

##### <a name="-nhc--package_ensure"></a>`package_ensure`

Data type: `Optional[String]`

The ensure state of package if using `install_method` of `repo` or `package`.

Default value: `undef`

##### <a name="-nhc--version"></a>`version`

Data type: `String`

The version of NHC to install.

Default value: `'1.4.3'`

##### <a name="-nhc--package_release"></a>`package_release`

Data type: `String`

The package release NHC to install. Not used if `install_method` is `source`.

Default value: `'1'`

##### <a name="-nhc--install_source"></a>`install_source`

Data type: `Optional[Variant[Stdlib::HTTPUrl,Stdlib::HTTPSUrl]]`

The source of install.
For `install_method` of `package` this is URL to package
For `install_method` of `source` this is git source URL

Default value: `undef`

##### <a name="-nhc--package_name"></a>`package_name`

Data type: `Optional[String]`

Name of the NHC package, not used with `install_method` of `source`.

Default value: `undef`

##### <a name="-nhc--repo_name"></a>`repo_name`

Data type: `Optional[String]`

The repo name for NHC, only used with `install_method` of `repo`.

Default value: `undef`

##### <a name="-nhc--source_dependencies"></a>`source_dependencies`

Data type: `Array`

The package dependencies for source install.

Default value: `['automake','make']`

##### <a name="-nhc--libexec_dir"></a>`libexec_dir`

Data type: `Stdlib::Absolutepath`

Location for libexec directory, OS dependent.

Default value: `'/usr/libexec'`

##### <a name="-nhc--checks"></a>`checks`

Data type: `Variant[Hash, Array]`

NHC checks for nhc.conf

Default value: `[]`

##### <a name="-nhc--settings"></a>`settings`

Data type: `Hash`

Settings to add to nhc.conf

Default value: `{}`

##### <a name="-nhc--settings_host"></a>`settings_host`

Data type: `Hash`

Host specific settings for nhc.conf

Default value: `{}`

##### <a name="-nhc--config_overrides"></a>`config_overrides`

Data type: `Hash`

Settings to add to /etc/sysconfig/nhc

Default value: `{}`

##### <a name="-nhc--detached_mode"></a>`detached_mode`

Data type: `Boolean`

Value for DETACHED_MODE

Default value: `false`

##### <a name="-nhc--detached_mode_fail_nodata"></a>`detached_mode_fail_nodata`

Data type: `Boolean`

Value for DETACHED_MODE_FAIL_NODATA

Default value: `false`

##### <a name="-nhc--program_name"></a>`program_name`

Data type: `String`

Value for NAME

Default value: `'nhc'`

##### <a name="-nhc--conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`

Path to NHC configuration directry

Default value: `'/etc/nhc'`

##### <a name="-nhc--conf_file"></a>`conf_file`

Data type: `Stdlib::Absolutepath`

Path for this configuration file

Default value: `'/etc/nhc/nhc.conf'`

##### <a name="-nhc--include_dir"></a>`include_dir`

Data type: `Stdlib::Absolutepath`

Path to directory containing NHC checks

Default value: `'/etc/nhc/scripts'`

##### <a name="-nhc--log_file"></a>`log_file`

Data type: `Stdlib::Absolutepath`

Path to log file

Default value: `'/var/log/nhc.log'`

##### <a name="-nhc--sysconfig_path"></a>`sysconfig_path`

Data type: `Stdlib::Absolutepath`

Path to sysconfig file

Default value: `'/etc/sysconfig/nhc'`

##### <a name="-nhc--manage_logrotate"></a>`manage_logrotate`

Data type: `Boolean`

Boolean that sets if logrotate resources should be managed

Default value: `true`

##### <a name="-nhc--log_rotate_every"></a>`log_rotate_every`

Data type: `String`

Frequency of logrotation

Default value: `'weekly'`

##### <a name="-nhc--custom_checks"></a>`custom_checks`

Data type: `Hash`

Hash passed to `nhc::custom_check`

Default value: `{}`

### <a name="nhc--config"></a>`nhc::config`

private class

### <a name="nhc--install"></a>`nhc::install`

private class

## Defined types

### <a name="nhc--conf"></a>`nhc::conf`

Manage NHC configurations

#### Examples

##### Define additional NHC configuration

```puppet
nhc::conf { 'nhc-cron':
  settings          => { 'NHC_RM' => 'slurm' },
  settings_host     => { 'c0001' => { 'FOO' => 'bar' }},
  checks            => { '*' => ['check_fs_free /tmp 10%'] },
  config_overrides  => { 'HOSTNAME' => '"$HOSTNAME_S"' },
}
```

#### Parameters

The following parameters are available in the `nhc::conf` defined type:

* [`ensure`](#-nhc--conf--ensure)
* [`checks`](#-nhc--conf--checks)
* [`settings`](#-nhc--conf--settings)
* [`settings_host`](#-nhc--conf--settings_host)
* [`config_overrides`](#-nhc--conf--config_overrides)
* [`detached_mode`](#-nhc--conf--detached_mode)
* [`detached_mode_fail_nodata`](#-nhc--conf--detached_mode_fail_nodata)
* [`program_name`](#-nhc--conf--program_name)
* [`conf_dir`](#-nhc--conf--conf_dir)
* [`conf_file`](#-nhc--conf--conf_file)
* [`include_dir`](#-nhc--conf--include_dir)
* [`sysconfig_path`](#-nhc--conf--sysconfig_path)
* [`log_file`](#-nhc--conf--log_file)

##### <a name="-nhc--conf--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of nhc::conf

Default value: `'present'`

##### <a name="-nhc--conf--checks"></a>`checks`

Data type: `Variant[Hash, Array]`

Checks to add to the configuration file

Default value: `[]`

##### <a name="-nhc--conf--settings"></a>`settings`

Data type: `Hash`

Settings to add to the configuration file

Default value: `{}`

##### <a name="-nhc--conf--settings_host"></a>`settings_host`

Data type: `Hash`

Settings specific to a hosts to add to the configuration file

Default value: `{}`

##### <a name="-nhc--conf--config_overrides"></a>`config_overrides`

Data type: `Hash`

Overrides for configuration in /etc/sysconfig/$name

Default value: `{}`

##### <a name="-nhc--conf--detached_mode"></a>`detached_mode`

Data type: `Boolean`

Value for DETACHED_MODE

Default value: `false`

##### <a name="-nhc--conf--detached_mode_fail_nodata"></a>`detached_mode_fail_nodata`

Data type: `Boolean`

Value for DETACHED_MODE_FAIL_NODATA

Default value: `false`

##### <a name="-nhc--conf--program_name"></a>`program_name`

Data type: `String`

Value for NAME

Default value: `$name`

##### <a name="-nhc--conf--conf_dir"></a>`conf_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Path to NHC configuration directry. Defaults to `/etc/nhc`

Default value: `undef`

##### <a name="-nhc--conf--conf_file"></a>`conf_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path for this configuration file. Defaults to `/etc/nhc/$name.conf`

Default value: `undef`

##### <a name="-nhc--conf--include_dir"></a>`include_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Path to directory containing NHC checks. Defaults to `/etc/nhc/scripts`

Default value: `undef`

##### <a name="-nhc--conf--sysconfig_path"></a>`sysconfig_path`

Data type: `Optional[Stdlib::Absolutepath]`

Path to sysconfig file. Defaults to `/etc/sysconfig/$name`

Default value: `undef`

##### <a name="-nhc--conf--log_file"></a>`log_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to log file. Defaults to `/var/log/$name.log`

Default value: `undef`

### <a name="nhc--custom_check"></a>`nhc::custom_check`

Add NHC custom check file

#### Examples

##### Define custom NHC check file

```puppet
nhc::custom_check { 'osc_gpfs':
  source => 'puppet:///modules/profile/nhc/osc_gpfs.nhc',
}
```

#### Parameters

The following parameters are available in the `nhc::custom_check` defined type:

* [`source`](#-nhc--custom_check--source)

##### <a name="-nhc--custom_check--source"></a>`source`

Data type: `Optional[String]`

The source of the custom check

Default value: `undef`

